@@ -9,7 +9,7 @@ my $bpm = shift || 100;
 my $t = Music::Percussion::Tabla->new(
     bpm    => $bpm,
     volume => 127,
-    # beats  => 4,
+    beats  => 8,
 );
 
 for (1 .. $t->beats) {
@@ -27,22 +27,22 @@ for (1 .. $t->beats) {
     # $t->note($t->quarter, 64); # ke quiet
     # $t->note($t->quarter, 77); # ke
     # $t->note($t->quarter, 79); # ke
-    # $t->note($t->quarter, 65); # ge
+    # $t->note($t->quarter, 65); # ga
     # $t->note($t->quarter, 66); # ge
     # $t->note($t->quarter, 76); # ge
-    # $t->note($t->quarter, 67); # dhun
-    # $t->note($t->quarter, 80); # dhun
     # $t->note($t->quarter, 71); # ta
     # $t->note($t->quarter, 75); # ta
     # $t->note($t->quarter, 85); # ta
-    # $t->note($t->quarter, 88); # ta ringing
-    # $t->note($t->quarter, 73); # tun
+    # $t->note($t->quarter, 88); # tun
     # $t->note($t->quarter, 78); # na
     # $t->note($t->quarter, 81); # na muted
     # $t->note($t->quarter, 62); # ?
     # $t->note($t->quarter, 69); # ?
     # $t->note($t->quarter, 74); # ? quiet
     # $t->note($t->quarter, 84); # ?
+    # $t->note($t->quarter, 67); # ?
+    # $t->note($t->quarter, 80); # ?
+    # $t->note($t->quarter, 73); # ?
 }
 
 $t->play_with_timidity;
